@@ -19,7 +19,7 @@ import json
 
 # Code zappette
 code_Fb= "35782633"
-
+log.msg("*****************************")
 class Freebox(IPlugin):
 	def __init__(self):
 		super(Freebox, self).__init__()
@@ -46,7 +46,7 @@ class Freebox(IPlugin):
 		log.msg("index :  %s" % (idex))	
 		
 	
-		for rs in self.configuration_plugin['param_Fb']:
+		for rs in self.configuration_plugin['param_fb']:
 			log.msg("ids  :  %s" % (rs['ids']))
 			if rs['ids'] == idex :
 
